==> nuiton-utils-1.1.1-sources.jar: org/nuiton/util/VersionConverter.java <==
/* 
 * *##% Nuiton utilities library
 * Copyright (C) 2004 - 2009 CodeLutin
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 *
 * You should have received a copy of the GNU General Lesser Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>. ##%* */
package org.nuiton.util;

import org.apache.commons.beanutils.ConversionException;
import org.apache.commons.beanutils.Converter;
import org.apache.commons.logging.LogFactory;
import static org.nuiton.i18n.I18n._;

/**
 * classe pour convertir une chaine en un objet Version.
 *
 * @author chemit
 * @see Version
 */
public class VersionConverter implements Converter {

    /** to use log facility, just put in your code: log.info(\"...\"); */
    private static final org.apache.commons.logging.Log log = LogFactory.getLog(VersionConverter.class);

    public VersionConverter() {
        if (log.isDebugEnabled()) {
            log.debug(this);
        }
    }

    @Override
    public Object convert(Class aClass, Object value) {
        if (value == null) {
            throw new ConversionException(_("lutinutil.error.convertor.noValue", this));
        }
        if (isEnabled(aClass)) {
            Object result;
            if (isEnabled(value.getClass())) {
                result = value;
                return result;
            }
            if (value instanceof String) {
                try {
                    result = VersionUtil.valueOf((String) value);
                    return result;
                } catch (IllegalArgumentException e) {
                    throw new ConversionException(_("lutinutil.error.version.convertor", value, this, e.getMessage()), e);
                }
            }
        }
        throw new ConversionException(_("lutinutil.error.no.convertor", aClass.getName(), value));
    }

    protected boolean isEnabled(Class<?> aClass) {
        return aClass == Version.class;
    }

    public Class<?> getType() {
        return Version.class;
    }
}

==> nuiton-utils-1.1.4-sources.jar: org/nuiton/util/VersionConverter.java <==
/* 
 * *##% Nuiton utilities library
 * Copyright (C) 2004 - 2009 CodeLutin
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 *
 * You should have received a copy of the GNU General Lesser Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>. ##%* */
package org.nuiton.util;

import org.apache.commons.beanutils.ConversionException;
import org.apache.commons.beanutils.Converter;
import org.apache.commons.logging.LogFactory;
import static org.nuiton.i18n.I18n._;

/**
 * classe pour convertir une chaine en un objet Version.
 *
 * @author chemit
 * @see Version
 */
public class VersionConverter implements Converter {

    /** to use log facility, just put in your code: log.info(\"...\"); */
    private static final org.apache.commons.logging.Log log = LogFactory.getLog(VersionConverter.class);

    public VersionConverter() {
        if (log.isDebugEnabled()) {
            log.debug(this);
        }
    }

    @Override
    public Object convert(Class aClass, Object value) {
        if (value == null) {
            throw new ConversionException(_("nuitonutil.error.convertor.noValue", this));
        }
        if (isEnabled(aClass)) {
            Object result;
            if (isEnabled(value.getClass())) {
                result = value;
                return result;
            }
            if (value instanceof String) {
                try {
                    result = VersionUtil.valueOf((String) value);
                    return result;
                } catch (IllegalArgumentException e) {
                    throw new ConversionException(_("nuitonutil.error.version.convertor", value, this, e.getMessage()), e);
                }
            }
        }
        throw new ConversionException(_("nuitonutil.error.no.convertor", aClass.getName(), value));
    }

    protected boolean isEnabled(Class<?> aClass) {
        return aClass == Version.class;
    }

    public Class<?> getType() {
        return Version.class;
    }
}
